# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.kubernetes_cluster_configuration import KubernetesClusterConfiguration
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError


class ConfigurationApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(ConfigurationApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def get(self, infrastructure_id, **kwargs):
        # type: (string_types, dict) -> KubernetesClusterConfiguration
        """Retrieve Kubernetes Cluster Configuration

        :param infrastructure_id: Id of the Kubernetes cluster
        :type infrastructure_id: string_types, required
        :return: Kubernetes Cluster Configuration
        :rtype: KubernetesClusterConfiguration
        """

        return self.api_client.get(
            '/encoding/infrastructure/kubernetes/{infrastructure_id}/configuration',
            path_params={'infrastructure_id': infrastructure_id},
            type=KubernetesClusterConfiguration,
            **kwargs
        )

    def update(self, infrastructure_id, kubernetes_cluster_configuration, **kwargs):
        # type: (string_types, KubernetesClusterConfiguration, dict) -> KubernetesClusterConfiguration
        """Update Kubernetes Cluster Configuration

        :param infrastructure_id: Id of the Kubernetes cluster
        :type infrastructure_id: string_types, required
        :param kubernetes_cluster_configuration: The Kubernetes Cluster Configuration which should be applied
        :type kubernetes_cluster_configuration: KubernetesClusterConfiguration, required
        :return: Kubernetes Cluster Configuration
        :rtype: KubernetesClusterConfiguration
        """

        return self.api_client.put(
            '/encoding/infrastructure/kubernetes/{infrastructure_id}/configuration',
            kubernetes_cluster_configuration,
            path_params={'infrastructure_id': infrastructure_id},
            type=KubernetesClusterConfiguration,
            **kwargs
        )



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.analytics_incident import AnalyticsIncident
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.analytics.alerting.incidents.analytics_incident_list_query_params import AnalyticsIncidentListQueryParams
from bitmovin_api_sdk.analytics.alerting.incidents.analytics_incident_list_by_license_key_query_params import AnalyticsIncidentListByLicenseKeyQueryParams


class IncidentsApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(IncidentsApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def list(self, query_params=None, **kwargs):
        # type: (AnalyticsIncidentListQueryParams, dict) -> AnalyticsIncident
        """List Incidents

        :param query_params: Query parameters
        :type query_params: AnalyticsIncidentListQueryParams
        :return: List of incidents
        :rtype: AnalyticsIncident
        """

        return self.api_client.get(
            '/analytics/alerting/incidents',
            query_params=query_params,
            pagination_response=True,
            type=AnalyticsIncident,
            **kwargs
        )

    def list_by_license_key(self, license_key, query_params=None, **kwargs):
        # type: (string_types, AnalyticsIncidentListByLicenseKeyQueryParams, dict) -> AnalyticsIncident
        """List Incidents per license

        :param license_key: License key
        :type license_key: string_types, required
        :param query_params: Query parameters
        :type query_params: AnalyticsIncidentListByLicenseKeyQueryParams
        :return: List of incidents
        :rtype: AnalyticsIncident
        """

        return self.api_client.get(
            '/analytics/alerting/incidents/{license_key}',
            path_params={'license_key': license_key},
            query_params=query_params,
            pagination_response=True,
            type=AnalyticsIncident,
            **kwargs
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class AnalyticsRuleMetric(Enum):
    AVG_VIDEO_STARTUPTIME = "AVG_VIDEO_STARTUPTIME"
    MEDIAN_VIDEO_STARTUPTIME = "MEDIAN_VIDEO_STARTUPTIME"



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
from bitmovin_api_sdk.models.kubernetes_cluster import KubernetesCluster
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.encoding.infrastructure.kubernetes.status.status_api import StatusApi
from bitmovin_api_sdk.encoding.infrastructure.kubernetes.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.infrastructure.kubernetes.configuration.configuration_api import ConfigurationApi
from bitmovin_api_sdk.encoding.infrastructure.kubernetes.agent_deployment.agent_deployment_api import AgentDeploymentApi
from bitmovin_api_sdk.encoding.infrastructure.kubernetes.prewarmed_deployment.prewarmed_deployment_api import PrewarmedDeploymentApi
from bitmovin_api_sdk.encoding.infrastructure.kubernetes.kubernetes_cluster_list_query_params import KubernetesClusterListQueryParams


class KubernetesApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(KubernetesApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.status = StatusApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.customdata = CustomdataApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.configuration = ConfigurationApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.agent_deployment = AgentDeploymentApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.prewarmed_deployment = PrewarmedDeploymentApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, kubernetes_cluster, **kwargs):
        # type: (KubernetesCluster, dict) -> KubernetesCluster
        """Connect Kubernetes Cluster

        :param kubernetes_cluster: The Kubernetes Cluster to be created
        :type kubernetes_cluster: KubernetesCluster, required
        :return: Kubernetes cluster
        :rtype: KubernetesCluster
        """

        return self.api_client.post(
            '/encoding/infrastructure/kubernetes',
            kubernetes_cluster,
            type=KubernetesCluster,
            **kwargs
        )

    def delete(self, infrastructure_id, **kwargs):
        # type: (string_types, dict) -> BitmovinResponse
        """Disconnect Kubernetes Cluster

        :param infrastructure_id: Id of the Kubernetes cluster
        :type infrastructure_id: string_types, required
        :return: Id of the Kubernetes cluster
        :rtype: BitmovinResponse
        """

        return self.api_client.delete(
            '/encoding/infrastructure/kubernetes/{infrastructure_id}',
            path_params={'infrastructure_id': infrastructure_id},
            type=BitmovinResponse,
            **kwargs
        )

    def get(self, infrastructure_id, **kwargs):
        # type: (string_types, dict) -> KubernetesCluster
        """Kubernetes Cluster Details

        :param infrastructure_id: Id of the Kubernetes cluster
        :type infrastructure_id: string_types, required
        :return: Kubernetes cluster
        :rtype: KubernetesCluster
        """

        return self.api_client.get(
            '/encoding/infrastructure/kubernetes/{infrastructure_id}',
            path_params={'infrastructure_id': infrastructure_id},
            type=KubernetesCluster,
            **kwargs
        )

    def list(self, query_params=None, **kwargs):
        # type: (KubernetesClusterListQueryParams, dict) -> KubernetesCluster
        """List Kubernetes Cluster

        :param query_params: Query parameters
        :type query_params: KubernetesClusterListQueryParams
        :return: List of Kubernetes clusters
        :rtype: KubernetesCluster
        """

        return self.api_client.get(
            '/encoding/infrastructure/kubernetes',
            query_params=query_params,
            pagination_response=True,
            type=KubernetesCluster,
            **kwargs
        )



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.analytics_alerting_rule import AnalyticsAlertingRule
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.analytics.alerting.rules.threshold.threshold_api import ThresholdApi
from bitmovin_api_sdk.analytics.alerting.rules.analytics_alerting_rule_list_query_params import AnalyticsAlertingRuleListQueryParams


class RulesApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(RulesApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.threshold = ThresholdApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def delete(self, license_key, rule_id, **kwargs):
        # type: (string_types, string_types, dict) -> AnalyticsAlertingRule
        """Delete Analytics Alerting Rule By License Key And Id

        :param license_key: License key
        :type license_key: string_types, required
        :param rule_id: Rule id
        :type rule_id: string_types, required
        :return: Alerting rule deleted
        :rtype: AnalyticsAlertingRule
        """

        return self.api_client.delete(
            '/analytics/alerting/rules/{license_key}/{rule_id}',
            path_params={'license_key': license_key, 'rule_id': rule_id},
            type=AnalyticsAlertingRule,
            **kwargs
        )

    def get(self, license_key, rule_id, **kwargs):
        # type: (string_types, string_types, dict) -> AnalyticsAlertingRule
        """Get Analytics Alerting Rule By License Key And Id

        :param license_key: License key
        :type license_key: string_types, required
        :param rule_id: Rule id
        :type rule_id: string_types, required
        :return: Analytics Alerting Rule
        :rtype: AnalyticsAlertingRule
        """

        return self.api_client.get(
            '/analytics/alerting/rules/{license_key}/{rule_id}',
            path_params={'license_key': license_key, 'rule_id': rule_id},
            type=AnalyticsAlertingRule,
            **kwargs
        )

    def list(self, query_params=None, **kwargs):
        # type: (AnalyticsAlertingRuleListQueryParams, dict) -> AnalyticsAlertingRule
        """List Analytics Alerting Rules

        :param query_params: Query parameters
        :type query_params: AnalyticsAlertingRuleListQueryParams
        :return: Service specific result
        :rtype: AnalyticsAlertingRule
        """

        return self.api_client.get(
            '/analytics/alerting/rules',
            query_params=query_params,
            pagination_response=True,
            type=AnalyticsAlertingRule,
            **kwargs
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
import pprint
import six


class AnalyticsIncident(object):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 rule_id=None,
                 start=None,
                 end=None,
                 is_recovered=None):
        # type: (string_types, string_types, string_types, string_types, bool) -> None

        self._id = None
        self._rule_id = None
        self._start = None
        self._end = None
        self._is_recovered = None
        self.discriminator = None

        if id_ is not None:
            self.id = id_
        if rule_id is not None:
            self.rule_id = rule_id
        if start is not None:
            self.start = start
        if end is not None:
            self.end = end
        if is_recovered is not None:
            self.is_recovered = is_recovered

    @property
    def openapi_types(self):
        types = {
            'id': 'string_types',
            'rule_id': 'string_types',
            'start': 'string_types',
            'end': 'string_types',
            'is_recovered': 'bool'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'id': 'id',
            'rule_id': 'ruleId',
            'start': 'start',
            'end': 'end',
            'is_recovered': 'isRecovered'
        }
        return attributes

    @property
    def id(self):
        # type: () -> string_types
        """Gets the id of this AnalyticsIncident.

        Incident id

        :return: The id of this AnalyticsIncident.
        :rtype: string_types
        """
        return self._id

    @id.setter
    def id(self, id_):
        # type: (string_types) -> None
        """Sets the id of this AnalyticsIncident.

        Incident id

        :param id_: The id of this AnalyticsIncident.
        :type: string_types
        """

        if id_ is not None:
            if not isinstance(id_, string_types):
                raise TypeError("Invalid type for `id`, type has to be `string_types`")

        self._id = id_

    @property
    def rule_id(self):
        # type: () -> string_types
        """Gets the rule_id of this AnalyticsIncident.

        Rule Id

        :return: The rule_id of this AnalyticsIncident.
        :rtype: string_types
        """
        return self._rule_id

    @rule_id.setter
    def rule_id(self, rule_id):
        # type: (string_types) -> None
        """Sets the rule_id of this AnalyticsIncident.

        Rule Id

        :param rule_id: The rule_id of this AnalyticsIncident.
        :type: string_types
        """

        if rule_id is not None:
            if not isinstance(rule_id, string_types):
                raise TypeError("Invalid type for `rule_id`, type has to be `string_types`")

        self._rule_id = rule_id

    @property
    def start(self):
        # type: () -> string_types
        """Gets the start of this AnalyticsIncident.

        Start date of the incident

        :return: The start of this AnalyticsIncident.
        :rtype: string_types
        """
        return self._start

    @start.setter
    def start(self, start):
        # type: (string_types) -> None
        """Sets the start of this AnalyticsIncident.

        Start date of the incident

        :param start: The start of this AnalyticsIncident.
        :type: string_types
        """

        if start is not None:
            if not isinstance(start, string_types):
                raise TypeError("Invalid type for `start`, type has to be `string_types`")

        self._start = start

    @property
    def end(self):
        # type: () -> string_types
        """Gets the end of this AnalyticsIncident.

        End date of the incident

        :return: The end of this AnalyticsIncident.
        :rtype: string_types
        """
        return self._end

    @end.setter
    def end(self, end):
        # type: (string_types) -> None
        """Sets the end of this AnalyticsIncident.

        End date of the incident

        :param end: The end of this AnalyticsIncident.
        :type: string_types
        """

        if end is not None:
            if not isinstance(end, string_types):
                raise TypeError("Invalid type for `end`, type has to be `string_types`")

        self._end = end

    @property
    def is_recovered(self):
        # type: () -> bool
        """Gets the is_recovered of this AnalyticsIncident.

        Recovery state of incident

        :return: The is_recovered of this AnalyticsIncident.
        :rtype: bool
        """
        return self._is_recovered

    @is_recovered.setter
    def is_recovered(self, is_recovered):
        # type: (bool) -> None
        """Sets the is_recovered of this AnalyticsIncident.

        Recovery state of incident

        :param is_recovered: The is_recovered of this AnalyticsIncident.
        :type: bool
        """

        if is_recovered is not None:
            if not isinstance(is_recovered, bool):
                raise TypeError("Invalid type for `is_recovered`, type has to be `bool`")

        self._is_recovered = is_recovered

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AnalyticsIncident):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
import pprint
import six


class AnalyticsThresholdRuleOptions(object):
    @poscheck_model
    def __init__(self,
                 threshold=None,
                 persistence=None,
                 sample_size=None,
                 recovery=None,
                 repeat_interval=None,
                 notify_on_resolved=None):
        # type: (float, int, int, int, int, bool) -> None

        self._threshold = None
        self._persistence = None
        self._sample_size = None
        self._recovery = None
        self._repeat_interval = None
        self._notify_on_resolved = None
        self.discriminator = None

        if threshold is not None:
            self.threshold = threshold
        if persistence is not None:
            self.persistence = persistence
        if sample_size is not None:
            self.sample_size = sample_size
        if recovery is not None:
            self.recovery = recovery
        if repeat_interval is not None:
            self.repeat_interval = repeat_interval
        if notify_on_resolved is not None:
            self.notify_on_resolved = notify_on_resolved

    @property
    def openapi_types(self):
        types = {
            'threshold': 'float',
            'persistence': 'int',
            'sample_size': 'int',
            'recovery': 'int',
            'repeat_interval': 'int',
            'notify_on_resolved': 'bool'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'threshold': 'threshold',
            'persistence': 'persistence',
            'sample_size': 'sampleSize',
            'recovery': 'recovery',
            'repeat_interval': 'repeatInterval',
            'notify_on_resolved': 'notifyOnResolved'
        }
        return attributes

    @property
    def threshold(self):
        # type: () -> float
        """Gets the threshold of this AnalyticsThresholdRuleOptions.

        Threshold for triggering alert (required)

        :return: The threshold of this AnalyticsThresholdRuleOptions.
        :rtype: float
        """
        return self._threshold

    @threshold.setter
    def threshold(self, threshold):
        # type: (float) -> None
        """Sets the threshold of this AnalyticsThresholdRuleOptions.

        Threshold for triggering alert (required)

        :param threshold: The threshold of this AnalyticsThresholdRuleOptions.
        :type: float
        """

        if threshold is not None:
            if not isinstance(threshold, (float, int)):
                raise TypeError("Invalid type for `threshold`, type has to be `float`")

        self._threshold = threshold

    @property
    def persistence(self):
        # type: () -> int
        """Gets the persistence of this AnalyticsThresholdRuleOptions.

        Persistence of threshold violation in minutes (required)

        :return: The persistence of this AnalyticsThresholdRuleOptions.
        :rtype: int
        """
        return self._persistence

    @persistence.setter
    def persistence(self, persistence):
        # type: (int) -> None
        """Sets the persistence of this AnalyticsThresholdRuleOptions.

        Persistence of threshold violation in minutes (required)

        :param persistence: The persistence of this AnalyticsThresholdRuleOptions.
        :type: int
        """

        if persistence is not None:
            if not isinstance(persistence, int):
                raise TypeError("Invalid type for `persistence`, type has to be `int`")

        self._persistence = persistence

    @property
    def sample_size(self):
        # type: () -> int
        """Gets the sample_size of this AnalyticsThresholdRuleOptions.

        Sample size for rule processing (required)

        :return: The sample_size of this AnalyticsThresholdRuleOptions.
        :rtype: int
        """
        return self._sample_size

    @sample_size.setter
    def sample_size(self, sample_size):
        # type: (int) -> None
        """Sets the sample_size of this AnalyticsThresholdRuleOptions.

        Sample size for rule processing (required)

        :param sample_size: The sample_size of this AnalyticsThresholdRuleOptions.
        :type: int
        """

        if sample_size is not None:
            if not isinstance(sample_size, int):
                raise TypeError("Invalid type for `sample_size`, type has to be `int`")

        self._sample_size = sample_size

    @property
    def recovery(self):
        # type: () -> int
        """Gets the recovery of this AnalyticsThresholdRuleOptions.

        Number of minutes without violation after which incident is considered as recovered (required)

        :return: The recovery of this AnalyticsThresholdRuleOptions.
        :rtype: int
        """
        return self._recovery

    @recovery.setter
    def recovery(self, recovery):
        # type: (int) -> None
        """Sets the recovery of this AnalyticsThresholdRuleOptions.

        Number of minutes without violation after which incident is considered as recovered (required)

        :param recovery: The recovery of this AnalyticsThresholdRuleOptions.
        :type: int
        """

        if recovery is not None:
            if not isinstance(recovery, int):
                raise TypeError("Invalid type for `recovery`, type has to be `int`")

        self._recovery = recovery

    @property
    def repeat_interval(self):
        # type: () -> int
        """Gets the repeat_interval of this AnalyticsThresholdRuleOptions.

        Interval for repeating notifications (required)

        :return: The repeat_interval of this AnalyticsThresholdRuleOptions.
        :rtype: int
        """
        return self._repeat_interval

    @repeat_interval.setter
    def repeat_interval(self, repeat_interval):
        # type: (int) -> None
        """Sets the repeat_interval of this AnalyticsThresholdRuleOptions.

        Interval for repeating notifications (required)

        :param repeat_interval: The repeat_interval of this AnalyticsThresholdRuleOptions.
        :type: int
        """

        if repeat_interval is not None:
            if not isinstance(repeat_interval, int):
                raise TypeError("Invalid type for `repeat_interval`, type has to be `int`")

        self._repeat_interval = repeat_interval

    @property
    def notify_on_resolved(self):
        # type: () -> bool
        """Gets the notify_on_resolved of this AnalyticsThresholdRuleOptions.

        Send notification after incident is resolved

        :return: The notify_on_resolved of this AnalyticsThresholdRuleOptions.
        :rtype: bool
        """
        return self._notify_on_resolved

    @notify_on_resolved.setter
    def notify_on_resolved(self, notify_on_resolved):
        # type: (bool) -> None
        """Sets the notify_on_resolved of this AnalyticsThresholdRuleOptions.

        Send notification after incident is resolved

        :param notify_on_resolved: The notify_on_resolved of this AnalyticsThresholdRuleOptions.
        :type: bool
        """

        if notify_on_resolved is not None:
            if not isinstance(notify_on_resolved, bool):
                raise TypeError("Invalid type for `notify_on_resolved`, type has to be `bool`")

        self._notify_on_resolved = notify_on_resolved

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AnalyticsThresholdRuleOptions):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from bitmovin_api_sdk.analytics.alerting.rules.rules_api import RulesApi
from bitmovin_api_sdk.analytics.alerting.rules.threshold.threshold_api import ThresholdApi
from bitmovin_api_sdk.analytics.alerting.rules.analytics_alerting_rule_list_query_params import AnalyticsAlertingRuleListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
from bitmovin_api_sdk.models.object_detection_bounding_box import ObjectDetectionBoundingBox
import pprint
import six


class ObjectDetectionResult(BitmovinResponse):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 detected_object=None,
                 timestamp=None,
                 score=None,
                 bounding_box=None):
        # type: (string_types, string_types, float, float, ObjectDetectionBoundingBox) -> None
        super(ObjectDetectionResult, self).__init__(id_=id_)

        self._detected_object = None
        self._timestamp = None
        self._score = None
        self._bounding_box = None
        self.discriminator = None

        if detected_object is not None:
            self.detected_object = detected_object
        if timestamp is not None:
            self.timestamp = timestamp
        if score is not None:
            self.score = score
        if bounding_box is not None:
            self.bounding_box = bounding_box

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(ObjectDetectionResult, self), 'openapi_types'):
            types = getattr(super(ObjectDetectionResult, self), 'openapi_types')

        types.update({
            'detected_object': 'string_types',
            'timestamp': 'float',
            'score': 'float',
            'bounding_box': 'ObjectDetectionBoundingBox'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(ObjectDetectionResult, self), 'attribute_map'):
            attributes = getattr(super(ObjectDetectionResult, self), 'attribute_map')

        attributes.update({
            'detected_object': 'detectedObject',
            'timestamp': 'timestamp',
            'score': 'score',
            'bounding_box': 'boundingBox'
        })
        return attributes

    @property
    def detected_object(self):
        # type: () -> string_types
        """Gets the detected_object of this ObjectDetectionResult.

        Name of the object that has been detected (in English)

        :return: The detected_object of this ObjectDetectionResult.
        :rtype: string_types
        """
        return self._detected_object

    @detected_object.setter
    def detected_object(self, detected_object):
        # type: (string_types) -> None
        """Sets the detected_object of this ObjectDetectionResult.

        Name of the object that has been detected (in English)

        :param detected_object: The detected_object of this ObjectDetectionResult.
        :type: string_types
        """

        if detected_object is not None:
            if not isinstance(detected_object, string_types):
                raise TypeError("Invalid type for `detected_object`, type has to be `string_types`")

        self._detected_object = detected_object

    @property
    def timestamp(self):
        # type: () -> float
        """Gets the timestamp of this ObjectDetectionResult.

        Time in seconds where the object was detected in the video

        :return: The timestamp of this ObjectDetectionResult.
        :rtype: float
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        # type: (float) -> None
        """Sets the timestamp of this ObjectDetectionResult.

        Time in seconds where the object was detected in the video

        :param timestamp: The timestamp of this ObjectDetectionResult.
        :type: float
        """

        if timestamp is not None:
            if not isinstance(timestamp, (float, int)):
                raise TypeError("Invalid type for `timestamp`, type has to be `float`")

        self._timestamp = timestamp

    @property
    def score(self):
        # type: () -> float
        """Gets the score of this ObjectDetectionResult.

        A number between 0 and 1 indicating the confidence of the detection

        :return: The score of this ObjectDetectionResult.
        :rtype: float
        """
        return self._score

    @score.setter
    def score(self, score):
        # type: (float) -> None
        """Sets the score of this ObjectDetectionResult.

        A number between 0 and 1 indicating the confidence of the detection

        :param score: The score of this ObjectDetectionResult.
        :type: float
        """

        if score is not None:
            if not isinstance(score, (float, int)):
                raise TypeError("Invalid type for `score`, type has to be `float`")

        self._score = score

    @property
    def bounding_box(self):
        # type: () -> ObjectDetectionBoundingBox
        """Gets the bounding_box of this ObjectDetectionResult.

        A box indicating the position and size of the detected object within the frame

        :return: The bounding_box of this ObjectDetectionResult.
        :rtype: ObjectDetectionBoundingBox
        """
        return self._bounding_box

    @bounding_box.setter
    def bounding_box(self, bounding_box):
        # type: (ObjectDetectionBoundingBox) -> None
        """Sets the bounding_box of this ObjectDetectionResult.

        A box indicating the position and size of the detected object within the frame

        :param bounding_box: The bounding_box of this ObjectDetectionResult.
        :type: ObjectDetectionBoundingBox
        """

        if bounding_box is not None:
            if not isinstance(bounding_box, ObjectDetectionBoundingBox):
                raise TypeError("Invalid type for `bounding_box`, type has to be `ObjectDetectionBoundingBox`")

        self._bounding_box = bounding_box

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(ObjectDetectionResult, self), "to_dict"):
            result = super(ObjectDetectionResult, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ObjectDetectionResult):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from bitmovin_api_sdk.analytics.alerting.alerting_api import AlertingApi
from bitmovin_api_sdk.analytics.alerting.rules.rules_api import RulesApi
from bitmovin_api_sdk.analytics.alerting.incidents.incidents_api import IncidentsApi



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.analytics_alerting_notification import AnalyticsAlertingNotification
from bitmovin_api_sdk.models.analytics_rule_metric import AnalyticsRuleMetric
from bitmovin_api_sdk.models.analytics_threshold_rule_options import AnalyticsThresholdRuleOptions
import pprint
import six


class AnalyticsAlertingRule(object):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 license_key=None,
                 type_=None,
                 name=None,
                 metric=None,
                 filters=None,
                 options=None,
                 notification=None):
        # type: (string_types, string_types, string_types, string_types, AnalyticsRuleMetric, list[AnalyticsAbstractFilter], AnalyticsThresholdRuleOptions, AnalyticsAlertingNotification) -> None

        self._id = None
        self._license_key = None
        self._type = None
        self._name = None
        self._metric = None
        self._filters = list()
        self._options = None
        self._notification = None
        self.discriminator = None

        if id_ is not None:
            self.id = id_
        if license_key is not None:
            self.license_key = license_key
        if type_ is not None:
            self.type = type_
        if name is not None:
            self.name = name
        if metric is not None:
            self.metric = metric
        if filters is not None:
            self.filters = filters
        if options is not None:
            self.options = options
        if notification is not None:
            self.notification = notification

    @property
    def openapi_types(self):
        types = {
            'id': 'string_types',
            'license_key': 'string_types',
            'type': 'string_types',
            'name': 'string_types',
            'metric': 'AnalyticsRuleMetric',
            'filters': 'list[AnalyticsAbstractFilter]',
            'options': 'AnalyticsThresholdRuleOptions',
            'notification': 'AnalyticsAlertingNotification'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'id': 'id',
            'license_key': 'licenseKey',
            'type': 'type',
            'name': 'name',
            'metric': 'metric',
            'filters': 'filters',
            'options': 'options',
            'notification': 'notification'
        }
        return attributes

    @property
    def id(self):
        # type: () -> string_types
        """Gets the id of this AnalyticsAlertingRule.

        The id of the alerting rule

        :return: The id of this AnalyticsAlertingRule.
        :rtype: string_types
        """
        return self._id

    @id.setter
    def id(self, id_):
        # type: (string_types) -> None
        """Sets the id of this AnalyticsAlertingRule.

        The id of the alerting rule

        :param id_: The id of this AnalyticsAlertingRule.
        :type: string_types
        """

        if id_ is not None:
            if not isinstance(id_, string_types):
                raise TypeError("Invalid type for `id`, type has to be `string_types`")

        self._id = id_

    @property
    def license_key(self):
        # type: () -> string_types
        """Gets the license_key of this AnalyticsAlertingRule.

        License key of the alerting rule

        :return: The license_key of this AnalyticsAlertingRule.
        :rtype: string_types
        """
        return self._license_key

    @license_key.setter
    def license_key(self, license_key):
        # type: (string_types) -> None
        """Sets the license_key of this AnalyticsAlertingRule.

        License key of the alerting rule

        :param license_key: The license_key of this AnalyticsAlertingRule.
        :type: string_types
        """

        if license_key is not None:
            if not isinstance(license_key, string_types):
                raise TypeError("Invalid type for `license_key`, type has to be `string_types`")

        self._license_key = license_key

    @property
    def type(self):
        # type: () -> string_types
        """Gets the type of this AnalyticsAlertingRule.

        Type of alerting rule

        :return: The type of this AnalyticsAlertingRule.
        :rtype: string_types
        """
        return self._type

    @type.setter
    def type(self, type_):
        # type: (string_types) -> None
        """Sets the type of this AnalyticsAlertingRule.

        Type of alerting rule

        :param type_: The type of this AnalyticsAlertingRule.
        :type: string_types
        """

        if type_ is not None:
            if not isinstance(type_, string_types):
                raise TypeError("Invalid type for `type`, type has to be `string_types`")

        self._type = type_

    @property
    def name(self):
        # type: () -> string_types
        """Gets the name of this AnalyticsAlertingRule.

        Alerting rule name (required)

        :return: The name of this AnalyticsAlertingRule.
        :rtype: string_types
        """
        return self._name

    @name.setter
    def name(self, name):
        # type: (string_types) -> None
        """Sets the name of this AnalyticsAlertingRule.

        Alerting rule name (required)

        :param name: The name of this AnalyticsAlertingRule.
        :type: string_types
        """

        if name is not None:
            if not isinstance(name, string_types):
                raise TypeError("Invalid type for `name`, type has to be `string_types`")

        self._name = name

    @property
    def metric(self):
        # type: () -> AnalyticsRuleMetric
        """Gets the metric of this AnalyticsAlertingRule.


        :return: The metric of this AnalyticsAlertingRule.
        :rtype: AnalyticsRuleMetric
        """
        return self._metric

    @metric.setter
    def metric(self, metric):
        # type: (AnalyticsRuleMetric) -> None
        """Sets the metric of this AnalyticsAlertingRule.


        :param metric: The metric of this AnalyticsAlertingRule.
        :type: AnalyticsRuleMetric
        """

        if metric is not None:
            if not isinstance(metric, AnalyticsRuleMetric):
                raise TypeError("Invalid type for `metric`, type has to be `AnalyticsRuleMetric`")

        self._metric = metric

    @property
    def filters(self):
        # type: () -> list[AnalyticsAbstractFilter]
        """Gets the filters of this AnalyticsAlertingRule.


        :return: The filters of this AnalyticsAlertingRule.
        :rtype: list[AnalyticsAbstractFilter]
        """
        return self._filters

    @filters.setter
    def filters(self, filters):
        # type: (list) -> None
        """Sets the filters of this AnalyticsAlertingRule.


        :param filters: The filters of this AnalyticsAlertingRule.
        :type: list[AnalyticsAbstractFilter]
        """

        if filters is not None:
            if not isinstance(filters, list):
                raise TypeError("Invalid type for `filters`, type has to be `list[AnalyticsAbstractFilter]`")

        self._filters = filters

    @property
    def options(self):
        # type: () -> AnalyticsThresholdRuleOptions
        """Gets the options of this AnalyticsAlertingRule.


        :return: The options of this AnalyticsAlertingRule.
        :rtype: AnalyticsThresholdRuleOptions
        """
        return self._options

    @options.setter
    def options(self, options):
        # type: (AnalyticsThresholdRuleOptions) -> None
        """Sets the options of this AnalyticsAlertingRule.


        :param options: The options of this AnalyticsAlertingRule.
        :type: AnalyticsThresholdRuleOptions
        """

        if options is not None:
            if not isinstance(options, AnalyticsThresholdRuleOptions):
                raise TypeError("Invalid type for `options`, type has to be `AnalyticsThresholdRuleOptions`")

        self._options = options

    @property
    def notification(self):
        # type: () -> AnalyticsAlertingNotification
        """Gets the notification of this AnalyticsAlertingRule.


        :return: The notification of this AnalyticsAlertingRule.
        :rtype: AnalyticsAlertingNotification
        """
        return self._notification

    @notification.setter
    def notification(self, notification):
        # type: (AnalyticsAlertingNotification) -> None
        """Sets the notification of this AnalyticsAlertingRule.


        :param notification: The notification of this AnalyticsAlertingRule.
        :type: AnalyticsAlertingNotification
        """

        if notification is not None:
            if not isinstance(notification, AnalyticsAlertingNotification):
                raise TypeError("Invalid type for `notification`, type has to be `AnalyticsAlertingNotification`")

        self._notification = notification

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AnalyticsAlertingRule):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.analytics_alerting_rule import AnalyticsAlertingRule
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError


class ThresholdApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(ThresholdApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, license_key, analytics_alerting_rule, **kwargs):
        # type: (string_types, AnalyticsAlertingRule, dict) -> AnalyticsAlertingRule
        """Create Analytics Alerting Rule

        :param license_key: License key
        :type license_key: string_types, required
        :param analytics_alerting_rule: Analytics alerting rule details to be created
        :type analytics_alerting_rule: AnalyticsAlertingRule, required
        :return: Created Analytics Alerting Rule
        :rtype: AnalyticsAlertingRule
        """

        return self.api_client.post(
            '/analytics/alerting/rules/{license_key}/threshold',
            analytics_alerting_rule,
            path_params={'license_key': license_key},
            type=AnalyticsAlertingRule,
            **kwargs
        )

    def update(self, license_key, rule_id, analytics_alerting_rule, **kwargs):
        # type: (string_types, string_types, AnalyticsAlertingRule, dict) -> AnalyticsAlertingRule
        """Update Analytics Alerting Rule

        :param license_key: License key
        :type license_key: string_types, required
        :param rule_id: Rule id
        :type rule_id: string_types, required
        :param analytics_alerting_rule: Analytics alerting rule details to be updated
        :type analytics_alerting_rule: AnalyticsAlertingRule, required
        :return: Updated Analytics Alerting Rule
        :rtype: AnalyticsAlertingRule
        """

        return self.api_client.put(
            '/analytics/alerting/rules/{license_key}/threshold/{rule_id}',
            analytics_alerting_rule,
            path_params={'license_key': license_key, 'rule_id': rule_id},
            type=AnalyticsAlertingRule,
            **kwargs
        )



from bitmovin_api_sdk.analytics.alerting.incidents.incidents_api import IncidentsApi
from bitmovin_api_sdk.analytics.alerting.incidents.analytics_incident_list_query_params import AnalyticsIncidentListQueryParams
from bitmovin_api_sdk.analytics.alerting.incidents.analytics_incident_list_by_license_key_query_params import AnalyticsIncidentListByLicenseKeyQueryParams



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.response_error import ResponseError


class StatusApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(StatusApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def get(self, infrastructure_id, **kwargs):
        # type: (string_types, dict) -> None
        """Kubernetes Cluster Status

        :param infrastructure_id: Id of the Kubernetes cluster
        :type infrastructure_id: string_types, required
        """

        self.api_client.get(
            '/encoding/infrastructure/kubernetes/{infrastructure_id}/status',
            path_params={'infrastructure_id': infrastructure_id},
            **kwargs
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.bitmovin_resource import BitmovinResource
from bitmovin_api_sdk.models.log_level import LogLevel
import pprint
import six


class PrewarmEncoderSettings(BitmovinResource):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 encoder_version=None,
                 min_prewarmed=None,
                 max_prewarmed=None,
                 log_level=None):
        # type: (string_types, string_types, string_types, datetime, datetime, dict, string_types, int, int, LogLevel) -> None
        super(PrewarmEncoderSettings, self).__init__(id_=id_, name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data)

        self._encoder_version = None
        self._min_prewarmed = None
        self._max_prewarmed = None
        self._log_level = None
        self.discriminator = None

        if encoder_version is not None:
            self.encoder_version = encoder_version
        if min_prewarmed is not None:
            self.min_prewarmed = min_prewarmed
        if max_prewarmed is not None:
            self.max_prewarmed = max_prewarmed
        if log_level is not None:
            self.log_level = log_level

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(PrewarmEncoderSettings, self), 'openapi_types'):
            types = getattr(super(PrewarmEncoderSettings, self), 'openapi_types')

        types.update({
            'encoder_version': 'string_types',
            'min_prewarmed': 'int',
            'max_prewarmed': 'int',
            'log_level': 'LogLevel'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(PrewarmEncoderSettings, self), 'attribute_map'):
            attributes = getattr(super(PrewarmEncoderSettings, self), 'attribute_map')

        attributes.update({
            'encoder_version': 'encoderVersion',
            'min_prewarmed': 'minPrewarmed',
            'max_prewarmed': 'maxPrewarmed',
            'log_level': 'logLevel'
        })
        return attributes

    @property
    def encoder_version(self):
        # type: () -> string_types
        """Gets the encoder_version of this PrewarmEncoderSettings.

        Encoder Version to be prewarmed. Only one encoder of this version can be prewarmed per cluster. (required)

        :return: The encoder_version of this PrewarmEncoderSettings.
        :rtype: string_types
        """
        return self._encoder_version

    @encoder_version.setter
    def encoder_version(self, encoder_version):
        # type: (string_types) -> None
        """Sets the encoder_version of this PrewarmEncoderSettings.

        Encoder Version to be prewarmed. Only one encoder of this version can be prewarmed per cluster. (required)

        :param encoder_version: The encoder_version of this PrewarmEncoderSettings.
        :type: string_types
        """

        if encoder_version is not None:
            if not isinstance(encoder_version, string_types):
                raise TypeError("Invalid type for `encoder_version`, type has to be `string_types`")

        self._encoder_version = encoder_version

    @property
    def min_prewarmed(self):
        # type: () -> int
        """Gets the min_prewarmed of this PrewarmEncoderSettings.

        The minimum number of prewarmed encoders of this Version (required)

        :return: The min_prewarmed of this PrewarmEncoderSettings.
        :rtype: int
        """
        return self._min_prewarmed

    @min_prewarmed.setter
    def min_prewarmed(self, min_prewarmed):
        # type: (int) -> None
        """Sets the min_prewarmed of this PrewarmEncoderSettings.

        The minimum number of prewarmed encoders of this Version (required)

        :param min_prewarmed: The min_prewarmed of this PrewarmEncoderSettings.
        :type: int
        """

        if min_prewarmed is not None:
            if not isinstance(min_prewarmed, int):
                raise TypeError("Invalid type for `min_prewarmed`, type has to be `int`")

        self._min_prewarmed = min_prewarmed

    @property
    def max_prewarmed(self):
        # type: () -> int
        """Gets the max_prewarmed of this PrewarmEncoderSettings.

        The maximum number of concurrent prewarmed encoders of this Version

        :return: The max_prewarmed of this PrewarmEncoderSettings.
        :rtype: int
        """
        return self._max_prewarmed

    @max_prewarmed.setter
    def max_prewarmed(self, max_prewarmed):
        # type: (int) -> None
        """Sets the max_prewarmed of this PrewarmEncoderSettings.

        The maximum number of concurrent prewarmed encoders of this Version

        :param max_prewarmed: The max_prewarmed of this PrewarmEncoderSettings.
        :type: int
        """

        if max_prewarmed is not None:
            if not isinstance(max_prewarmed, int):
                raise TypeError("Invalid type for `max_prewarmed`, type has to be `int`")

        self._max_prewarmed = max_prewarmed

    @property
    def log_level(self):
        # type: () -> LogLevel
        """Gets the log_level of this PrewarmEncoderSettings.


        :return: The log_level of this PrewarmEncoderSettings.
        :rtype: LogLevel
        """
        return self._log_level

    @log_level.setter
    def log_level(self, log_level):
        # type: (LogLevel) -> None
        """Sets the log_level of this PrewarmEncoderSettings.


        :param log_level: The log_level of this PrewarmEncoderSettings.
        :type: LogLevel
        """

        if log_level is not None:
            if not isinstance(log_level, LogLevel):
                raise TypeError("Invalid type for `log_level`, type has to be `LogLevel`")

        self._log_level = log_level

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(PrewarmEncoderSettings, self), "to_dict"):
            result = super(PrewarmEncoderSettings, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PrewarmEncoderSettings):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.output import Output
import pprint
import six


class AkamaiNetStorageOutput(Output):
    @poscheck_model
    def __init__(self,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 id_=None,
                 acl=None,
                 host=None,
                 username=None,
                 password=None):
        # type: (string_types, string_types, datetime, datetime, dict, string_types, list[AclEntry], string_types, string_types, string_types) -> None
        super(AkamaiNetStorageOutput, self).__init__(name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data, id_=id_, acl=acl)

        self._host = None
        self._username = None
        self._password = None
        self.discriminator = None

        if host is not None:
            self.host = host
        if username is not None:
            self.username = username
        if password is not None:
            self.password = password

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(AkamaiNetStorageOutput, self), 'openapi_types'):
            types = getattr(super(AkamaiNetStorageOutput, self), 'openapi_types')

        types.update({
            'host': 'string_types',
            'username': 'string_types',
            'password': 'string_types'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(AkamaiNetStorageOutput, self), 'attribute_map'):
            attributes = getattr(super(AkamaiNetStorageOutput, self), 'attribute_map')

        attributes.update({
            'host': 'host',
            'username': 'username',
            'password': 'password'
        })
        return attributes

    @property
    def host(self):
        # type: () -> string_types
        """Gets the host of this AkamaiNetStorageOutput.

        Host to use for Akamai NetStorage transfers (required)

        :return: The host of this AkamaiNetStorageOutput.
        :rtype: string_types
        """
        return self._host

    @host.setter
    def host(self, host):
        # type: (string_types) -> None
        """Sets the host of this AkamaiNetStorageOutput.

        Host to use for Akamai NetStorage transfers (required)

        :param host: The host of this AkamaiNetStorageOutput.
        :type: string_types
        """

        if host is not None:
            if not isinstance(host, string_types):
                raise TypeError("Invalid type for `host`, type has to be `string_types`")

        self._host = host

    @property
    def username(self):
        # type: () -> string_types
        """Gets the username of this AkamaiNetStorageOutput.

        Your Akamai NetStorage Username (required)

        :return: The username of this AkamaiNetStorageOutput.
        :rtype: string_types
        """
        return self._username

    @username.setter
    def username(self, username):
        # type: (string_types) -> None
        """Sets the username of this AkamaiNetStorageOutput.

        Your Akamai NetStorage Username (required)

        :param username: The username of this AkamaiNetStorageOutput.
        :type: string_types
        """

        if username is not None:
            if not isinstance(username, string_types):
                raise TypeError("Invalid type for `username`, type has to be `string_types`")

        self._username = username

    @property
    def password(self):
        # type: () -> string_types
        """Gets the password of this AkamaiNetStorageOutput.

        Your Akamai NetStorage password (required)

        :return: The password of this AkamaiNetStorageOutput.
        :rtype: string_types
        """
        return self._password

    @password.setter
    def password(self, password):
        # type: (string_types) -> None
        """Sets the password of this AkamaiNetStorageOutput.

        Your Akamai NetStorage password (required)

        :param password: The password of this AkamaiNetStorageOutput.
        :type: string_types
        """

        if password is not None:
            if not isinstance(password, string_types):
                raise TypeError("Invalid type for `password`, type has to be `string_types`")

        self._password = password

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(AkamaiNetStorageOutput, self), "to_dict"):
            result = super(AkamaiNetStorageOutput, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AkamaiNetStorageOutput):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
